@@ -177,4 +177,8 @@ SUPPORTED_COUNTRYS = [
 ]
 
 SUPPORTED_COUNTRY_NAMES = [item["name"] for item in SUPPORTED_COUNTRYS]
-DEFAULT_COUNTRY_NAME = "United States"
\ No newline at end of file
+DEFAULT_COUNTRY_NAME = "United States"
+CONF_LOGIN_RESPONSE = "login_response"
+CONF_SELECTED_HOUSE = "selected_house"
+CONF_DEVICE_LIST = "device_list"
+CONF_PRODUCT_LIST = "product_list"
